﻿/// <reference path="../../TypeDefinitions/jquery/jquery.d.ts"/>

function inedopg_initmodal(o) {
    var initActionButtonContainer = function () {
        /// <summary>Ensures that the appropriate action button container for the modal is positioned correctly.</summary>
        /// <returns type="void"/>
        $('.action-button-container').last().addClass('fixed');

        // Add a spacer for the fixed action-button-container
        $('#divOverflow').append('<div style="height: 50px; visibility: hidden;">&nbsp;</div>');
    };

    if (parent.jQuery && parent.jQuery.fn.inedojq_frameddialog && window.name) {
        var pjq = parent.jQuery;

        var $iframe = pjq('iframe[name=""' + window.name + '""]');
        var $dialog = $iframe.parent();
        var $dialogTitle = $dialog.find('.ui-dialog-title');
        $dialogTitle.text($('title').text());

        o.minHeight = o.minHeight || $dialog.height();

        // Make sure any previous help button has been removed
        $dialog.find('.dialog-help-button').remove();

        // If there is a help URL specified, add it to the dialog title
        if (o.helpUrl) {
            var $helpButton = pjq('<a target="_blank" title="help" class="dialog-help-button SmallHelpIcon"></a>');
            $helpButton.attr('href', o.helpUrl);
            $dialogTitle.parent().append($helpButton);
            $helpButton.click(function () {
                window.open(o.helpUrl, '', 'width=800,height=600,location=no,menubar=no,toolbar=no,resizable=yes,scrollbars=yes');
                return false;
            });
        }

        initActionButtonContainer();

        var sizeModal = function (animationSpeed) {
            var setdims = { height: o.height, width: o.width };

            // If height is not specified, calculate it
            if (!setdims.height) {
                // Always include a 50px padding
                var calculatedHeight = 50;

                $('#divOverflow').css({
                    'width': pjq(parent).width(),
                    'visibility': 'hidden'
                });

                $('#divOverflow').children().each(function () {
                    calculatedHeight += $(this).height();
                });
                $('#divOverflow').css({
                    'width': 'auto'
                });
                setdims.height = Math.max(calculatedHeight, o.minHeight);
            }

            // If width is not specified, leave it alone
            if (!setdims.width)
                setdims.width = Math.max($iframe.width(), o.minWidth);

            $(window).bind('mousewheel', function (event) {
                var getWheelDirection = function (eventData) {
                    /// <summary>Cross-browser test for scroll direction.</summary>
                    /// <param name="eventData" value="{wheelDelta:0,deltaY:0,detail:0}">Original mousewheel event.</param>
                    /// <returns type="Number">-1 for up, 1 for down, 0 for unknown.</returns>
                    if (eventData) {
                        if (eventData.wheelDelta)
                            return eventData.wheelDelta < 0 ? 1 : -1;

                        if (eventData.deltaY)
                            return eventData.deltaY < 0 ? -1 : 1;

                        if (eventData.detail)
                            return eventData.detail < 0 ? -1 : 1;
                    }

                    return 0;
                };

                var delta = getWheelDirection(event.originalEvent);
                if (delta != 0) {
                    var pos = $(window).scrollTop();

                    if (delta < 0)
                        return pos > 0;
                    else
                        return pos < $(document).height() - $(window).height();
                }
            });

            // Make sure size does not exceed the parent window size
            setdims.width = Math.min(setdims.width, pjq(parent).width() - 50);
            setdims.height = Math.min(setdims.height, pjq(parent).height() - 50);

            // If any of the dimensions are significantly different, resize the dialog
            if (Math.abs(setdims.height - $iframe.height()) > 50 || Math.abs(setdims.width - $iframe.width()) > 50) {
                var parentHeight = pjq(parent).height();
                var parentWidth = pjq(parent).width();

                var borderHeight = $dialog.height() - $iframe.height();
                var borderWidth = $dialog.width() - $iframe.width();

                var yPos = (parentHeight - (setdims.height + borderHeight)) / 2;
                var xPos = (parentWidth - (setdims.width + borderWidth)) / 2;

                var dialogcss = {
                    width: setdims.width,
                    height: setdims.height + 34,
                    top: yPos,
                    left: xPos
                };

                var setiframecss = function () {
                    $iframe.css({
                        visibility: 'visible',
                        width: setdims.width,
                        height: setdims.height
                    });
                    $('#divOverflow').css('visibility', 'visible');
                };

                if (animationSpeed) {
                    $('#divOverflow').css('visibility', 'hidden');
                    $iframe.css('visibility', 'hidden');
                    $dialog.animate(dialogcss, { duration: animationSpeed, complete: setiframecss });
                } else {
                    $('#divOverflow').css('visibility', 'hidden');
                    $iframe.css('visibility', 'hidden');
                    $dialog.animate(dialogcss, { duration: 0, complete: setiframecss });
                }
            } else {
                $('#divOverflow').css('visibility', 'visible');
            }
        };

        sizeModal(1000 / 4);

        $(window).bind('modalResize', function () {
            sizeModal();
        });
    } else {
        var winHeight = ($(window).height() - 28);
        $('#divOverflow').css('height', winHeight + 'px');
        initActionButtonContainer();
    }
}
